<?php
//////////////////////////
//
// constants.php
//
// Author: Albert Teoh
// Date: 17.11.2005
//
// Contains all the relevant constants used by the Pulsar Data Archive
//////////////////////////


///////////////////////////////////////////////////////////////////


////////////////////
// Database
//
////

// Database connection constants

define('DB_NAME', 'psrchive');
define('DB_SERVER','localhost'); // herschel.atnf.csiro.au 
define('DB_PORT','3306');
define('DB_ADMIN','psrdba'); // Need to be admin so that rows can be deleted
define('DB_USERNAME','pulsar'); // Just a read only user. Helps to prevent SQL injection
define('DB_PASS','lighthouse');

// Database table names
define ('USERS_TABLE', 'users');
define ('OBSERVATIONS_TABLE', 'observations');
define ('CALS_TABLE', 'cals');

// Field names for the observations table
define('DATA_LOCATION', 'data_loc');
define('FILENAME', 'filename');
define('PULSAR_NAME', 'pulsar_name');
define('PERIOD', 'period');
define('DM', 'dm');
define('RA', 'ra');
define('DEC', 'dec');
define('FREQUENCY', 'freq');
define('MJD', 'MJD');
define('LENGTH', 'length');
define('BW', 'bw');

define('NSUB', 'nsub');
define('NBIN', 'nbin');
define('FILESIZE', 'file_size_bytes');
define('TSAMP', 'tsamp');
define('NBEAM', 'nbeam');

////////////////////
// Locations
//
////

define('DATA_ARCH_DIR', "/var/www/vhosts/pulsararchive.atnf.csiro.au/htdocs");
define("FIX_LD_LIB","LD_LIBRARY_PATH=/pulsar/psr/packages/linux/qt/lib:/pulsar/psr/packages/linux/pgplot:/usr/local/lib ");
define('PSRCAT', "/pulsar/psr/linux/bin/psrcat"); 
//define('PSRCAT', "psrcat");
define('CONVERT', "/usr/local/bin/convert -rotate 90");

// Directory where psrchive routines are located
define('PSRCHIVE_DIR', "/var/www/vhosts/pulsararchive.atnf.csiro.au/apps/");

// Scratch disk
define('SCR1', "/pulsar/scratch01/");

// Directory where processed files will reside
define('WORKING_DIR', SCR1."/data_archive");

// Directory containing the scrunched profiles
define('PROFILE_DIR', WORKING_DIR."/profile_images");

// Directory where logs will be located. Relative path.
define('LOG_DIR', "logs");

///////////////////////////
// This locations are relative to the current directory 
//

define('DATA_ARCHIVE_URL', "http://pulsararchive-int.atnf.csiro.au");

// The location of the tarred up archive files that the user has requested for download
define('WEB_DOWNLOADS_DIR',"downloads");

// Directory containing images of pulse profiles
define('WEB_PROFILE_DIR',WEB_DOWNLOADS_DIR."/profile_images");

// An odd constant...but necessary. This is the extension given to a pulsar archive
// directory name which contains all the respective FTp scrunched profiles.
// E.g. In $WBC there will be a J0437-4715 (observations) and a J0437-4715S (FTp scrunched)
define('SCRUNCHED_DIR_EXT', 'S');

define('SCRUNCHED_FILE_EXT', 'FTp');

define('PASSWORDS_FILE', DATA_ARCH_DIR.'/../pw');

////////////////////////////
// Environment variables
//

define('PATH',"/pulsar/psr/sungcc/bin:/pulsar/psr/bin/sungcc:/pulsar/psr/csh_script:/pulsar/psr/packages/bin/sungcc:/pulsar/psr/packages/sungcc/bin:/usr/local/mpi/bin:/pulsar/psr/packages/sungcc/qt/bin:.:/nfs/aips++/stable-19_1189/sun4sol_gnu/bin:/nfs/atapplic/ftools/sparc-sun-solaris2.6/scripts:/nfs/atapplic/ftools/sparc-sun-solaris2.6/bin:/nfs/applic/miriad/bin/sun4sol:/nfs/atapplic/multibeam/bin:/nfs/atapplic/multibeam/sun4sol:/nfs/atapplic/slap/sun4sol:/usr/local/grads/bin:/usr/local/jdk/bin:/usr/local/jdk/bin:/usr/local/karma/cm_script:/usr/local/karma/csh_script:/usr/local/karma/site/sparc_Solaris/bin:/usr/local/karma/static-bin:/usr/local/karma/bin:/usr/local/texmf/bin:/usr/local/unixstat/bin:/usr/local/wincenter:/usr/openwin/bin:/usr/local/X11/bin:/opt/SUNWspro/bin:/usr/ccs/bin:/opt/SUNWste/bin:/usr/local/gnu/bin:/usr/local/site/bin:/usr/local/bin:/usr/ccs/bin:/usr/bin:/bin:/usr/ucb:/usr/local/jdk/bin:/usr/local/gildas/bin:/nfs/online/1.9/bin");
define('PSRHOME', "/pulsar/psr");
define('PGPLOT_FONT', "/pulsar/psr/packages/sungcc/pgplot/grfont.dat");
define('LD_LIBRARY_PATH', "/u/teo003/software/sungcc/lib:/pulsar/psr/packages/sungcc/qt/lib:/pulsar/psr/packages/sungcc/pgplot:/usr/local/lib:/pulsar/psr/packages/sungcc/qt/lib:/pulsar/psr/packages/sungcc/pgplot:/usr/local/lib:/pulsar/psr/packages/sungcc/qt/lib:/pulsar/psr/packages/sungcc/pgplot:/usr/local/lib:/nfs/aips++/stable-19_1189/sun4sol_gnu/lib:/usr/local/lib:/nfs/atapplic/ftools/sparc-sun-solaris2.6/lib:/usr/openwin/lib:/usr/local/X11/lib:/usr/dt/lib:/opt/SUNWspro/lib:/usr/local/gnu/lib:/usr/local/lib:/usr/lib:/lib:/usr/ucblib:/usr/local/gnu/lib:/usr/local/gnu/lib/gcc-lib/sparc-sun-solaris2.6/2.95.3:/usr/xpg4/lib:/usr/xpg4/lib");
define('PSRCAT_FILE', "/pulsar/psr/runtime/psrcat/psrcat.db");//"/pulsar/psr/cvshome/teo003/soft_atnf/psrcat/database/psrcat.db"; //"/home/ateoh/software/psrcat/database/psrcat.db";
define('PGPLOT_DIR', "/u/teo003/software/sungcc/pgplot");

///////////////////////////
//
// People
//
define('REGISTRATION_ADMIN_EMAIL',"albert.teoh@csiro.au");

define('DICK_MANCHESTER', "rmanchester");
define('GEORGE_HOBBS', "ghobbs");
define('ALBERT_TEOH', "ateoh");
define('SIMON_JOHNSTON', "sjohnston");

// Once the data archive system administrator has marked 
// someone for deletion, the system will wait this number
// of days before completely deleting this person from the
// database

define('DAYS_BEFORE_DELETE', 7);

//////////////////////////////
// Profile display constants
//

// The default number of columns to display if just displaying the profiles
define('NUM_PROFILE_COLUMNS', 1);
define('NUM_PROFILE_ROWS', 1);

// Default number of columns to display if displaying both the profiles and cals
define('NUM_CAL_COLUMNS', 2);
define('NUM_CAL_ROWS', 2);


/////////////////////
// Miscellaneous
//

// The image type to convert to from ps
define('IMAGE_EXT', "png"); // gif

// Machine to use when calling psrchive routines
//define('MACHINE', "electra");

// Plot types
define('PROFILE_PLOT', "profile");


// Maps the form's plot options to the command needed to generate the plot
//$PLOT_COMMANDS = array (PROFILE_PLOT => PSRCHIVE_DIR."/pav -D -K /png"); //".IMAGE_EXT);
//$PLOT_COMMANDS = array (PROFILE_PLOT => PSRCHIVE_DIR."/pav -DFTp -K /pulsar/scratch01/data_archive/profile_images");
define('PLOT_DIR', "/pulsar/scratch01/data_archive/profile_images");
$PLOT_COMMANDS = array (PROFILE_PLOT => FIX_LD_LIB."/pulsar/psr/linux/bin/pav -DFTp -K -g ".PLOT_DIR);

// Number of rows to limit by per page
define('MAX_DISPLAY_ROWS', 20);
define('MAX_DISPLAY_PAGES', 10);


// Return codes for login authentication
define('OK', -1, true);
define('INIT', 1, true);
define('BAD_LOGIN', 2, true);

// Define a few labels
define('REMOVE_FROM_CART', "Remove observations");
define('ADD_TO_CART', "Add observations to cart");
define('VIEW_PROFILES', "View selected profiles");
define('VIEW_PROFILES_CALS', "View selected profiles with cals");

define('DOWNLOAD_ALL_OBS_CALS', "Download all observations and cals in cart");
define('DOWNLOAD_ALL_OBS', "Download all observations (only) in cart");
define('DOWNLOAD_ALL_CALS', "Download all cals (only) in cart");

define('HOURS2DEGS',360/24);

// Some colours
define('OBS_SELECTED_EVEN', '#DCBEBE');
define('OBS_SELECTED_ODD', '#D2AAAA');

// Registration

// Number of days that a registration request stays in the database before being deleted
// If the delete_date value in the database is null, it will never be deleted
define('PENDING_REGISTRATION_PERIOD', '7');

// The maximum download limit of 10 GB
define('MAX_DOWNLOAD_MB', 10000); 

?>
